@@ -156,8 +156,7 @@ T Transitiondata::typechecker(int colno, int arg)
 					const vector<int>& v = as<vector<int>>(colobj);   
 					auto minmax = std::minmax_element(v.begin(), v.end());
 					good = !(0 > *minmax.first || 1 < *minmax.second);
-				} else
-					good = false;
+				}
 			}
 			errstr += " neither an ordered factor nor an integer vector with all values either 0 or 1";
 			break;
@@ -347,7 +346,8 @@ inline IntegerVector prevres_intvec(DataFrame object, const char* subject, const
 //'   to R \code{Dates} conveniently using \code{\link{as.Date}()}. If only \emph{year} information is
 //'   available, arbitrary values could be used consistently for month and day e.g., 1st of January of
 //'   each year; likewise, the first day of each month could be used arbitrary, if only the
-//'   \emph{year} and \emph{month} were known.
+//'   \emph{year} and \emph{month} were known. See vignette 
+//'   \href{../doc/convertDate.pdf}{Converting numeric values to class \code{"Date"}} for examples.
 //'
 //' Quantitive results available as \code{\link{numeric}} data can be converted to a semi-quantitative
 //'   \code{\link[base:factor]{ordered factor}} conveniently using \code{\link{cut}()} (see \emph{examples}).
@@ -452,7 +452,7 @@ IntegerVector get_transitions(
 //' PreviousDate
 //'
 //' @description
-//' \code{get_prev_dates()} identifies the previous test date for individual subjects and timepoints
+//' \code{get_prev_date()} identifies the previous test date for individual subjects and timepoints
 //' in a longitudinal study.
 //'
 //' \code{add_prev_date()} interpolates these previous test dates into a data frame for further analysis.
@@ -475,8 +475,8 @@ IntegerVector get_transitions(
 //'    column named as specified by argument \code{prev_date} of class \code{\link{Date}} containing
 //'    the values of the previous test dates.}
 //'
-//' \item{\code{get_prev_date()}}{An \code{vector} of length \code{\link{nrow}(object)},
-//'    class \code{\link{Date}}, containing the values of the previous test dates ordered in the exact
+//' \item{\code{get_prev_date()}}{A \code{vector} of class \code{\link{Date}}, length
+//'    \code{\link{nrow}(object)}, containing the values of the previous test dates ordered in the exact
 //'    sequence of the \code{subject} and \code{timepoint} in \code{object}.}
 //'
 //'
@@ -500,50 +500,6 @@ IntegerVector get_transitions(
 //'
 //' rm(Blackmore)
 //'
-//' ###
-//' ## Example on formatting numeric values as R dates
-//'
-//' #  Data frame containing year as numeric: 2018 to 2025
-//' (df <- data.frame(
-//'     subject = rep(1001:1003),
-//'     timepoint = rep(2018:2025, each = 3),
-//'     result = gl(3, 4, lab = c("jolly", "good", "show"), ordered = TRUE)
-//'     ))
-//'
-//' #  Convert to R dates
-//' df <- transform(df,
-//'            timepoint = as.Date(paste(timepoint, "01", "01", sep = "-"))
-//'       )
-//'
-//'   # Add column of test result transitions (defaults: cap = 0, modulate = 0)
-//' (df <- add_transitions(df))
-//'
-//' # Format R dates just to show the year
-//' transform(df, timepoint = format(timepoint, "%Y"))
-//'
-//' #  Data frame containing year and month as numeric: July 2024 to June 2025
-//' (df <- data.frame(
-//'            subject = 1001:1002,
-//'            year = rep(2024:2025, each = 12),
-//'            month = rep(c(7:12, 1:6), each = 2),
-//'            result = gl(2, 3, lab = c("low", "high"), ordered = TRUE)
-//'        ))
-//'
-//' #  Convert to R dates
-//' df <- transform(df, timepoint = as.Date(paste(year, month, "01", sep = "-")))
-//' \dontshow{
-//'     df$year <- NULL
-//'     df$month <- NULL
-//' }
-//'
-//'   # Add column of test result transitions (defaults: cap = 0, modulate = 0)
-//' (df <- add_transitions(df))
-//'
-//' # Format R dates just to show the month and year
-//' transform(df, timepoint = format(timepoint, "%b-%Y"))
-//'
-//' rm(df)
-//'
 // [[Rcpp::export]]
 DataFrame add_prev_date(
 	DataFrame object, const char* subject = "subject",
@@ -588,7 +544,7 @@ DateVector get_prev_date(DataFrame object, const char* subject = "subject", cons
 //' PreviousResult
 //'
 //' @description
-//' \code{get_prev_results()} identifies the previous test result for individual subjects and timepoints
+//' \code{get_prev_result()} identifies the previous test result for individual subjects and timepoints
 //' in a longitudinal study.
 //'
 //' \code{add_prev_result()} interpolates these previous test results into a data frame for further analysis.
